Citation
========
If you use this code in your research, please cite the :download:`IAC 2024 conference paper <_static/stephenson_bskrl_2024.pdf>`.

APA
---
.. code-block:: 

   M. Stephenson and H. Schaub, “BSK-RL: Modular, High-Fidelity Reinforcement Learning Environments for Spacecraft Tasking,” International Astronautical Congress, Milan, Italy, Oct. 14–18 2024.

BibTeX
------
.. code-block:: 

    @inproceedings{stephenson_bskrl_2024,
        title = {{{BSK-RL}}: {{Modular}}, {{High-Fidelity Reinforcement Learning Environments}} for {{Spacecraft Tasking}}},
        booktitle = {75th {{International Astronautical Congress}}},
        author = {Stephenson, Mark A and Schaub, Hanspeter},
        year = {2024},
        month = oct,
        publisher = {IAF},
        address = {Milan, Italy},
        langid = {english},
    }